@@ -23,10 +23,12 @@
 #by wctang <wctang@csie.nctu.edu.tw> and using the tool cnmap
 #(http://search.cpan.org/~qjzhou/Encode-CNMap-0.32/bin/cnmap) by Qing-Jie Zhou <qjzhou@hotmail.com>.
 #
-$ModulesDescription .= '<p>$Id: chinese_cn-utf8.pl,v 1.8 2006/05/10 22:52:16 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: chinese_cn-utf8.pl,v 1.9 2006/08/18 22:46:10 as Exp $</p>';
 %Translate = split(/\n/,<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
 禁止读取：使用者、ip 或是网路已被禁止连线。
+%s calls
+
 Could not create %s
 无法建立 %s
 Invalid UserName %s: not saved.
@@ -37,6 +39,14 @@ This page contains an uploaded file:
 本页包含一个已上传的文件：
 Recursive include of %s!
 
+Clear Cache
+
+Main lock obtained.
+取得主要锁定。
+Main lock released.
+释放主要锁定。
+Comments on this page
+对本页发表评论
 XML::RSS is not available on this system.
 本系统无法使用 XML::RSS 。
 diff
@@ -79,14 +89,6 @@ Preview only, not yet saved
 现在是预览模式，尚未储存
 Please go on to %s.
 请继续前住 %s 。
-Could not open %s log file
-无法打开日志文件 %s
-Error was
-错误是
-Note: This error is normal if no changes have been made.
-如果还没有做过任何修改的话，则不用理会这个错误讯息。
-Could not open old %s log file
-无法打开旧的 %s 日志文件
 No updates since %s
 自 %s 以来没有修改
 Updates since %s
@@ -101,6 +103,10 @@ List latest change per page only
 只列出每个页面最新的修改
 List all changes
 列出所有的修改
+Skip rollbacks
+
+Include rollbacks
+
 List only major changes
 只列出主要的修改
 Include minor changes
@@ -137,20 +143,34 @@ History of %s
 %s 的历史记录
 Compare
 比较
+Deleted
+
+Mark this page for deletion
+
+No other revisions available
+
+current
+
 Revision %s
 第 %s 版本
-by
-由
-Rolling back changes
-恢复修改
+Contributors to %s
+
 Missing target for rollback.
 找不到要恢复的目标
 Target for rollback is too far back.
 要恢复的目标过于久远。
+Rolling back changes
+恢复修改
+The two revisions are the same.
+
+Editing not allowed for %s.
+不允许编辑 %s 。
 Rollback to %s
 恢复至 %s
 %s rolled back
 %s 已恢复
+to %s
+
 Index of all pages
 所有页面的索引
 Wiki Version
@@ -219,6 +239,8 @@ View current revision
 参阅目前版本
 View all changes
 列出所有的修改
+View contributors
+
 Homepage URL:
 首页网址：
 s
@@ -239,28 +261,26 @@ Validate HTML
 验证 HTML
 Validate CSS
 验证 CSS
-Difference (from revision %1 to %2)
+Last edit
+
+Difference between revision %1 and %2
 差异（从第 %1 版到%2）
 revision %s
 第 %s 版
 current revision
 目前的版本
-Difference (from prior %s revision)
-差异（从先前的第 %s 版本）
-major
-主要
-minor
-次要
+Last major edit (%s)
+
+later minor edits
+
 No diff available.
 没有差异。
-The two revisions are the same.
-
 Old revision:
 旧版本：
 Changed:
 修改：
-Removed:
-删除：
+Deleted:
+
 Added:
 增加：
 to
@@ -331,10 +351,10 @@ Summary:
 摘要：
 This change is a minor edit.
 这次的修改是次要的。
-Replace this file with text.
-用文字来取代本档。
-Replace this text with a file.
-用文件来取代本文。
+Replace this file with text
+用文字来取代本档
+Replace this text with a file
+用文件来取代本文
 File to upload: 
 要上传的文件：
 Files of type %s are not allowed.
@@ -357,6 +377,10 @@ This operation is restricted to site editors only...
 这个动作限定只允许编辑者使用…
 This operation is restricted to administrators only...
 这个动作限定只允许管理者使用…
+SampleUndefinedPage
+
+Sample_Undefined_Page
+
 Rule "%1" matched "%2" on this page.
 本页的 "%2" 符合规则 "%1"。
 Without normal pages
@@ -395,24 +419,8 @@ Near pages:
 相邻页面：
 last updated
 最后更新于
-Complete Content
-完整内容
-The main page is %s.
-首页是 %s 。
-Comments on this page
-对本页发表评论
-Editing not allowed for %s.
-不允许编辑 %s 。
-SampleUndefinedPage
-
-%s cannot be defined.
-无法指定 %s 为页面名称。
-Sample_Undefined_Page
-
-[[%s]] cannot be defined.
-无法指定 [[%s]] 为页面名称。
-Only an administrator can create %s.
-只有管理者可以建立 %s 。
+by
+由
 Transfer Error: %s
 传输错误：%s
 Browser reports no file info.
@@ -453,8 +461,6 @@ Maintenance not done.
 (管理每 12 小时只能进行一次。)
 Remove the "maintain" file or wait.
 移除 "maintain" 档，或等时间到了再进行。
-Main lock obtained.
-取得主要锁定。
 Expiring keep files and deleting pages marked for deletion
 清除过期的库存档和删除已标记的文件
 not deleted: 
@@ -463,12 +469,16 @@ deleted
 已删除
 Moving part of the %s log file.
 移除部分在 %s 日志文件中的数据。
+Could not open %s log file
+无法打开日志文件 %s
+Error was
+错误是
+Note: This error is normal if no changes have been made.
+如果还没有做过任何修改的话，则不用理会这个错误讯息。
 Moving %s log entries.
 移除了 %s 个记录项目。
 Getting page index file for %s.
 自 %s 取得页面索引数据。
-Main lock released.
-释放主要锁定。
 Set or Remove global edit lock
 设定或移除整个网站的编辑锁定
 Edit lock created.
@@ -529,6 +539,10 @@ Rename %s to:
 将 %s 重命名为:
 Learn more...
 
+Complete Content
+完整内容
+The main page is %s.
+首页是 %s 。
 Cannot highlight the language %s.
 无法高亮显示语言 %s 。
 Recent Visitors
@@ -779,8 +793,16 @@ Download this page as PDF
 
 Portrait
 肖像
+Publish %s
+
+No target wiki was specified in the config file.
+
+The target wiki was misconfigured.
+
 You did not answer correctly.
 回答不正确。
+To save this page you must answer this question:
+
 All Referrers
 所有的引用者
 Referrers
@@ -805,6 +827,12 @@ Result pages:
 
 (%s results)
 
+Tags:
+
+Tags: %s.
+
+No tags
+
 Slideshow:%s
 
 Static Copy
@@ -859,6 +887,12 @@ http://www.pricescan.com/books/BookDetail.asp?isbn=%s
 
 search
 搜索
+Wanted Pages
+
+%s pages
+
+%s, referenced from:
+
 Upload of %s file
 
 Blog
@@ -869,4 +903,8 @@ New
 
 Edit %s.
 
+Title: 
+
+Tags: 
+
 END_OF_TRANSLATION
