@@ -180,7 +180,7 @@ sub CreateClusterMap {
 sub ClusterMapDoRc {
 	my ( @options ) = @_;
 	my $page = "";
-	my $cluster = GetParam('cluster');
+	my $cluster = GetParam(rcclusteronly);
 	
 	if ($cluster ne "") {
 		CreateClusterMap();
@@ -254,7 +254,7 @@ sub ClusterMapPrintWikiToHTML {
 	# display a map.
 	if (($ClusterMapPage eq $OpenPageName)
 		&& ($pageText =~ /^\s*$/s)){
-		SetParam('cluster',0);
+		SetParam('rcclusteronly',0);
 		CreateClusterMap();
 	if ($ClusterMapTOC) {
 		my $TOCCount = 0;
