@@ -16,7 +16,7 @@
 #    59 Temple Place, Suite 330
 #    Boston, MA 02111-1307 USA
 
-$ModulesDescription .= '<p>$Id: image.pl,v 1.24 2006/03/06 15:36:53 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: image.pl,v 1.25 2006/09/01 23:46:53 as Exp $</p>';
 
 use vars qw($ImageUrlPath);
 
@@ -28,7 +28,7 @@ push(@MyRules, \&ImageSupportRule);
 
 sub ImageSupportRule {
   my $result = undef;
-  if (m!\G\[\[image((/[a-z]+)*)( external)?:($FreeLinkPattern|$FullUrlPattern)(\|[^]|]+)?(\|($FreeLinkPattern|$FullUrlPattern|))?(\|[^]|]+)?(\|($FreeLinkPattern|$FullUrlPattern))?\]\]!gc) {
+  if (m!\G\[\[image((/[a-z]+)*)( external)?:([^]|]+)(\|[^]|]+)?(\|[^]|]*)?(\|[^]|]*)?(\|[^]|]*)?\]\]!gc) {
     my $oldpos = pos;
     my $class = 'image' . $1;
     my $external = $3;
@@ -36,39 +36,28 @@ sub ImageSupportRule {
     # Don't generate an alt text if none was specified, since the rule
     # forces you to pick an alt text if you're going to provide a
     # link target.
-    my $alt = $7 ? substr($7, 1) : '';
-    my $link = $8 ? substr($8, 1) : '';
-    my $caption = $12 ? substr($12, 1) : '';
-    my $reference = $14;
-#     my $count = 1;
-#     foreach my $s ($1, $2, $3, $4, $5, $6, $7, $8, $9, $10, $11, $12, $13, $14) {
-#       warn $count++, ': ', $s;
-#     }
+    my $alt = $5 ? substr($5, 1) : '';
+    my $link = $6 ? substr($6, 1) : '';
+    my $caption = $7 ? substr($7, 1) : '';
+    my $reference = $8 ? substr($8, 1) : '';
     my $id = FreeToNormal($name);
     $class =~ s!/! !g;
     my $linkclass = $class;
     # link to the image if no link was given
-    if (not $link) {
-      if ($external) {
-        if ($name =~ /$FullUrlPattern/) {
-	  ($link, $linkclass) = ImageGetExternalUrl($name, $linkclass);
-        } else {
-	  # not an outside link!
-          $link = $ImageUrlPath . '/' . UrlEncode($name);
-        }
-      } else {
-        ($link, $linkclass) = ImageGetExternalUrl($id, $linkclass);
-      }
-    } else {
+    $link = $name unless $link;
+    if ($link =~ /^($FullUrlPattern|$FreeInterLinkPattern)$/
+	or $link =~ /^$FreeLinkPattern$/ and not $external) {
       ($link, $linkclass) = ImageGetExternalUrl($link, $linkclass);
-    }
-    my $src;
-    if ($name =~ /$FullUrlPattern/) {
-      $src = UnquoteHtml($name);
-    } elsif ($external) {
-      $src = $ImageUrlPath . '/' . UrlEncode($name);
     } else {
-      $src = ImageGetInternalUrl($id);
+      $link = ImageUrlEncode($ImageUrlPath . '/' . $link);
+    }
+    my $src = $name;
+    if ($src =~ /^($FullUrlPattern|$FreeInterLinkPattern)$/) {
+      ($src) = ImageGetExternalUrl($src);
+    } elsif ($src =~ /^$FreeLinkPattern$/ and not $external) {
+      $src = ImageGetInternalUrl($src);
+    } else {
+      $src = ImageUrlEncode($ImageUrlPath . '/' . $name);
     }
     $result = $q->img({-src=>$src, -alt=>$alt, -title=>$alt, -class=>'upload'});
     $result = $q->a({-href=>$link, -class=>$linkclass}, $result);
@@ -86,11 +75,20 @@ sub ImageSupportRule {
   return $result;
 }
 
+sub ImageUrlEncode {
+  # url encode everything except for slashes
+  return join('/', map { UrlEncode($_) } split(/\//, shift));
+}
+
 sub ImageGetExternalUrl {
   my ($link, $class) = @_;
-  if ($link =~ /$FullUrlPattern/) {
+  if ($link =~ /^$FullUrlPattern$/) {
     $link = UnquoteHtml($link);
     $class .= ' outside';
+  } elsif ($link =~ /^$FreeInterLinkPattern$/) {
+    my ($site, $page) = split(/:/, $link, 2);
+    $link = GetInterSiteUrl($site, $page, 1); # quote!
+    $class .= ' inter ' . $site;
   } else {
     if (substr($link, 0, 1) eq '/') {
       # do nothing -- relative URL on the same server
