@@ -40,7 +40,7 @@ sub process {
 
 package OddMuse;
 
-$ModulesDescription .= '<p>$Id: search-freetext.pl,v 1.45 2006/06/13 19:40:29 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: search-freetext.pl,v 1.50 2006/08/17 14:06:04 as Exp $</p>';
 
 push(@MyRules, \&SearchFreeTextTagsRule);
 
@@ -67,8 +67,8 @@ push(@MyAdminCode, \&SearchFreeTextMenu);
 sub SearchFreeTextMenu {
   my ($id, $menuref, $restref) = @_;
   push(@$menuref,
-       ScriptLink('action=buildindex', T('Rebuild index for searching')),
-       ScriptLink('action=cloud', T('Tag Cloud')));
+       ScriptLink('action=buildindex', T('Rebuild index for searching'), 'buildindex'),
+       ScriptLink('action=cloud', T('Tag Cloud'), 'cloud'));
 }
 
 $Action{buildindex} = \&SearchFreeTextIndex;
@@ -122,7 +122,7 @@ $Action{cloud} = \&SearchFreeTextCloud;
 
 sub SearchFreeTextCloud {
   print GetHeader('', T('Tag Cloud'), ''),
-    $q->start_div({-class=>'content cloud'} . '<p>');
+    $q->start_div({-class=>'content cloud'}) . '<p>';
   if (not eval { require Search::FreeText;  }) {
     my $err = $@;
     ReportError(T('Search::FreeText is not available on this system.'), '500 INTERNAL SERVER ERROR');
@@ -137,7 +137,8 @@ sub SearchFreeTextCloud {
   # use Data::Dumper;
   # print Dumper($db), '<br />';
   foreach (keys %$db) {
-    next if /^[\t ]|[0-9:]/;
+    # next if /^[\t ]|[0-9:]/;
+    next if /^[\t ]/;
     $count{$_} = split(/;/, $$db{$_});
     $max = $count{$_} if $count{$_} > $max;
     $min = $count{$_} if not $min or $count{$_} < $min;
@@ -148,7 +149,7 @@ sub SearchFreeTextCloud {
     print $q->a({-href  => "$ScriptName?search=tag:" . UrlEncode($_),
 		 -title => $n,
 		 -style => 'font-size: '
-		 . int(80+120*($n-$min)/($max-$min)) . '%;',
+		 . int(80+120*($max == $min ? 1 : ($n-$min)/($max-$min))) . '%;',
 		}, $_), T(' ... ');
   }
   $tags->close_index();
@@ -322,8 +323,8 @@ sub NewSearchFreePrintFooter {
 		    $q->endform());
     } elsif ($id and @tags) {
       print $q->div({-class=>'tags'},
-		    $q->p(T('Tags: '), map { $_ = "\[\[tag:$_\]\]";
-					     SearchFreeTextTagsRule(); } @tags));
+		    $q->p(T('Tags:'), map { $_ = "\[\[tag:$_\]\]";
+					    SearchFreeTextTagsRule(); } @tags));
     }
   }
   OldSearchFreePrintFooter(@_);
