@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005  Alex Schroeder <alex@emacswiki.org>
+# Copyright (C) 2004, 2005, 2006  Alex Schroeder <alex@emacswiki.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,15 +16,15 @@
 #    59 Temple Place, Suite 330
 #    Boston, MA 02111-1307 USA
 
-$ModulesDescription .= '<p>$Id: static-copy.pl,v 1.19 2005/12/29 16:02:08 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: static-copy.pl,v 1.22 2006/08/13 23:10:49 as Exp $</p>';
 
 $Action{static} = \&DoStatic;
 
 use vars qw($StaticDir $StaticAlways %StaticMimeTypes $StaticUrl);
 
 $StaticDir = '/tmp/static';
-$StaticUrl = '';                # change this!
-$StaticFilesAlways = 0;       # 1 = uploaded files only, 2 = all pages
+$StaticUrl = '';           # change this!
+$StaticAlways = 0;         # 1 = uploaded files only, 2 = all pages
 
 my $StaticMimeTypes = '/etc/mime.types';
 my %StaticFiles;
@@ -38,7 +38,6 @@ sub DoStatic {
     print GetHeader('', T('Static Copy'), '');
   }
   CreateDir($StaticDir);
-  %StaticMimeTypes = StaticMimeTypes() unless %StaticMimeTypes;
   %StaticFiles = ();
   StaticWriteFiles();
   print '</p>' unless $raw;
@@ -85,11 +84,12 @@ sub StaticScriptLink {
 sub StaticGetDownloadLink {
   my ($name, $image, $revision, $alt) = @_; # ignore $revision
   $alt = $name unless $alt;
+  $alt =~ s/_/ /g;
   my $id = FreeToNormal($name);
-  AllPagesList();
   # if the page does not exist
   return '[' . ($image ? 'image' : 'link') . ':' . $name . ']' unless $IndexHash{$id};
   if ($image) {
+    return StaticFileName($id) if $image == 2;
     my $result = $q->img({-src=>StaticFileName($id), -alt=>$alt, -class=>'upload'});
     $result = ScriptLink($id, $result, 'image');
     return $result;
@@ -110,6 +110,7 @@ sub StaticFileName {
   my %hash = ParseData($data);
   my $ext = '.html';
   if ($hash{text} =~ /^\#FILE ([^ \n]+)\n(.*)/s) {
+    %StaticMimeTypes = StaticMimeTypes() unless %StaticMimeTypes;
     $ext = $StaticMimeTypes{$1};
     $ext = '.' . $ext if $ext;
   }
@@ -259,6 +260,7 @@ sub GetDownloadLink {
     } else {
       $action = $ScriptName . '?' . $action;
     }
+    return $action if $image == 2;
     my $result = $q->img({-src=>$action, -alt=>$alt, -class=>'upload'});
     $result = ScriptLink(UrlEncode($id), $result, 'image') unless $id eq $OpenPageName;
     return $result;
